@@ -1,6 +1,6 @@
 use crate::backend::backend_type::BackendType;
 use crate::backend::{unalias_backend, ABackend};
-use crate::config::CONFIG;
+use crate::config::Config;
 use crate::plugins::PluginType;
 use crate::registry::REGISTRY;
 use crate::toolset::install_state::InstallStateTool;
@@ -113,7 +113,7 @@ impl BackendArg {
             return backend_type;
         }
         if config::is_loaded() {
-            if let Some(repo_url) = CONFIG.get_repo_url(&self.short) {
+            if let Some(repo_url) = Config::get().get_repo_url(&self.short) {
                 return if repo_url.contains("vfox-") {
                     BackendType::Vfox
                 } else {
@@ -128,20 +128,22 @@ impl BackendArg {
     pub fn full(&self) -> String {
         let short = unalias_backend(&self.short);
         if config::is_loaded() {
-            if let Some(full) = CONFIG
+            if let Some(full) = Config::get()
                 .all_aliases
                 .get(short)
                 .and_then(|a| a.backend.clone())
             {
                 return full;
             }
-            if let Some(url) = CONFIG.repo_urls.get(short) {
+            if let Some(url) = Config::get().repo_urls.get(short) {
                 deprecated!("config_plugins", "[plugins] section of mise.toml is deprecated. Use [alias] instead. https://mise.jdx.dev/dev-tools/aliases.html");
                 return format!("asdf:{url}");
             }
         }
         if let Some(full) = &self.full {
             full.clone()
+        } else if let Some(full) = install_state::get_tool_full(short).unwrap_or_default() {
+            full
         } else if let Some(pt) = install_state::get_plugin_type(short).unwrap_or_default() {
             match pt {
                 PluginType::Asdf => format!("asdf:{short}"),
@@ -251,26 +253,28 @@ impl Hash for BackendArg {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::test::reset;
     use pretty_assertions::{assert_eq, assert_str_eq};
 
     #[test]
     fn test_backend_arg() {
-        reset();
         let t = |s: &str, full, tool_name, t| {
             let fa: BackendArg = s.into();
             assert_str_eq!(full, fa.full());
             assert_str_eq!(tool_name, fa.tool_name);
             assert_eq!(t, fa.backend_type());
         };
+        #[cfg(unix)]
         let asdf = |s, full, name| t(s, full, name, BackendType::Asdf);
         let cargo = |s, full, name| t(s, full, name, BackendType::Cargo);
         // let core = |s, full, name| t(s, full, name, BackendType::Core);
         let npm = |s, full, name| t(s, full, name, BackendType::Npm);
         let vfox = |s, full, name| t(s, full, name, BackendType::Vfox);
 
-        asdf("asdf:poetry", "asdf:poetry", "poetry");
-        asdf("poetry", "asdf:mise-plugins/mise-poetry", "poetry");
+        #[cfg(unix)]
+        {
+            asdf("asdf:poetry", "asdf:poetry", "poetry");
+            asdf("poetry", "asdf:mise-plugins/mise-poetry", "poetry");
+        }
         cargo("cargo:eza", "cargo:eza", "eza");
         // core("node", "node", "node");
         npm("npm:@antfu/ni", "npm:@antfu/ni", "@antfu/ni");
@@ -284,7 +288,6 @@ mod tests {
 
     #[test]
     fn test_backend_arg_pathname() {
-        reset();
         let t = |s: &str, expected| {
             let fa: BackendArg = s.into();
             let actual = fa.installs_path.to_string_lossy();
