@@ -1,11 +1,15 @@
-use crate::config::Config;
+use crate::config::{Config, SETTINGS};
+use crate::shell::ShellType;
+use crate::task::Task;
 use crate::tera::{get_tera, BASE_CONTEXT};
 use eyre::Result;
 use indexmap::IndexMap;
 use itertools::Itertools;
 use std::collections::HashMap;
+use std::iter::once;
 use std::path::PathBuf;
 use std::sync::{Arc, Mutex};
+use usage::parse::ParseValue;
 use xx::regex;
 
 pub struct TaskScriptParser {
@@ -269,7 +273,7 @@ impl TaskScriptParser {
         }
         let scripts = scripts
             .iter()
-            .map(|s| tera.render_str(s, &ctx).unwrap())
+            .map(|s| tera.render_str(s.trim(), &ctx).unwrap())
             .collect();
         let mut cmd = usage::SpecCommand::default();
         // TODO: ensure no gaps in args, e.g.: 1,2,3,4,5
@@ -292,6 +296,7 @@ impl TaskScriptParser {
 }
 
 pub fn replace_template_placeholders_with_args(
+    task: &Task,
     spec: &usage::Spec,
     scripts: &[String],
     args: &[String],
@@ -304,17 +309,34 @@ pub fn replace_template_placeholders_with_args(
     let mut out = vec![];
     let re = regex!(r"MISE_TASK_ARG:(\w+):MISE_TASK_ARG");
     for script in scripts {
+        let shell_type: Option<ShellType> = shell_from_shebang(script)
+            .or(task.shell())
+            .unwrap_or(SETTINGS.default_inline_shell()?)[0]
+            .parse()
+            .ok();
+        let escape = |v: &ParseValue| match v {
+            ParseValue::MultiString(_) => {
+                // these are already escaped
+                v.to_string()
+            }
+            _ => match shell_type {
+                Some(ShellType::Zsh | ShellType::Bash | ShellType::Fish) => {
+                    shell_words::quote(&v.to_string()).to_string()
+                }
+                _ => v.to_string(),
+            },
+        };
         let mut script = script.clone();
         for (arg, value) in &m.args {
             script = script.replace(
                 &format!("MISE_TASK_ARG:{}:MISE_TASK_ARG", arg.name),
-                &value.to_string(),
+                &escape(value),
             );
         }
         for (flag, value) in &m.flags {
             script = script.replace(
                 &format!("MISE_TASK_ARG:{}:MISE_TASK_ARG", flag.name),
-                &value.to_string(),
+                &escape(value),
             );
         }
         script = re.replace_all(&script, "").to_string();
@@ -327,12 +349,23 @@ pub fn has_any_args_defined(spec: &usage::Spec) -> bool {
     !spec.cmd.args.is_empty() || !spec.cmd.flags.is_empty()
 }
 
+fn shell_from_shebang(script: &str) -> Option<Vec<String>> {
+    let shebang = script.lines().next()?.strip_prefix("#!")?;
+    let shebang = shebang.strip_prefix("/usr/bin/env -S").unwrap_or(shebang);
+    let shebang = shebang.strip_prefix("/usr/bin/env").unwrap_or(shebang);
+    let mut parts = shebang.split_whitespace();
+    let shell = parts.next()?;
+    let args = parts.map(|s| s.to_string()).collect_vec();
+    Some(once(shell.to_string()).chain(args).collect())
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
 
     #[test]
     fn test_task_parse_arg() {
+        let task = Task::default();
         let parser = TaskScriptParser::new(None);
         let scripts = vec!["echo {{ arg(i=0, name='foo') }}".to_string()];
         let (scripts, spec) = parser.parse_run_scripts(&None, &scripts).unwrap();
@@ -341,12 +374,14 @@ mod tests {
         assert_eq!(arg0.name, "foo");
 
         let scripts =
-            replace_template_placeholders_with_args(&spec, &scripts, &["abc".to_string()]).unwrap();
+            replace_template_placeholders_with_args(&task, &spec, &scripts, &["abc".to_string()])
+                .unwrap();
         assert_eq!(scripts, vec!["echo abc"]);
     }
 
     #[test]
     fn test_task_parse_arg_var() {
+        let task = Task::default();
         let parser = TaskScriptParser::new(None);
         let scripts = vec!["echo {{ arg(var=true) }}".to_string()];
         let (scripts, spec) = parser.parse_run_scripts(&None, &scripts).unwrap();
@@ -355,6 +390,7 @@ mod tests {
         assert_eq!(arg0.name, "0");
 
         let scripts = replace_template_placeholders_with_args(
+            &task,
             &spec,
             &scripts,
             &["abc".to_string(), "def".to_string()],
@@ -365,6 +401,7 @@ mod tests {
 
     #[test]
     fn test_task_parse_flag() {
+        let task = Task::default();
         let parser = TaskScriptParser::new(None);
         let scripts = vec!["echo {{ flag(name='foo') }}".to_string()];
         let (scripts, spec) = parser.parse_run_scripts(&None, &scripts).unwrap();
@@ -373,13 +410,14 @@ mod tests {
         assert_eq!(&flag.name, "foo");
 
         let scripts =
-            replace_template_placeholders_with_args(&spec, &scripts, &["--foo".to_string()])
+            replace_template_placeholders_with_args(&task, &spec, &scripts, &["--foo".to_string()])
                 .unwrap();
         assert_eq!(scripts, vec!["echo true"]);
     }
 
     #[test]
     fn test_task_parse_option() {
+        let task = Task::default();
         let parser = TaskScriptParser::new(None);
         let scripts = vec!["echo {{ option(name='foo') }}".to_string()];
         let (scripts, spec) = parser.parse_run_scripts(&None, &scripts).unwrap();
@@ -388,6 +426,7 @@ mod tests {
         assert_eq!(&option.name, "foo");
 
         let scripts = replace_template_placeholders_with_args(
+            &task,
             &spec,
             &scripts,
             &["--foo".to_string(), "abc".to_string()],
